---
title: '[2025년 1월] 서비스 이용약관 개정 변경 안내'
category: 공지사항
searchTags:
  - 서비스유료화
  - 개정변경
  - 이용약관
datetime: 2024-12-30T03:32:57.425Z
---

안녕하세요\~! 포트원 입니다.

항상 포트원을 이용해주시는 고객 여러분께 진심으로 감사드립니다.\
2025년 1월 31일 아래와 같이 서비스 이용약관이 변경됨을 사전 안내 드립니다.

- 공고일 : 2024.12.30(월)
- 시행일 : 2025.1.31(목)

<Highlight text="변경내용" />

<Accordion title="▶ 제 27조 유료플랜 이용요금에 대한 이의신청 및 반환" image="https://help.portone.io/uploads/이용약관 27조.png" />

> 현재 버전 보러 가기

[코리아포트원 서비스이용약관(개정일:2024.11.11)](https://terms.portone.io/?_gl=1*171hbom*_gcl_au*NDcyNjE2NTQ0LjE3MjkwNDY3Nzg.*_ga*MTQzNTc5MTIyMi4xNzIxMTg2MTIx*_ga_PD0FDL16NZ*MTczNTUzNDk4MS4yMDMuMC4xNzM1NTM0OTg2LjU1LjAuMA..)
